/* Decimal Float Rounding Mode accessor function prototype
 
   Copyright (C) 2006 IBM Corporation.
   Copyright (C) 2009-2015 Free Software Foundation, Inc.

   Author(s): Ryan S. Arnold <rsa@us.ibm.com>

   The Decimal Floating Point C Library is free software; you can
   redistribute it and/or modify it under the terms of the GNU Lesser
   General Public License version 2.1.

   The Decimal Floating Point C Library is distributed in the hope that
   it will be useful, but WITHOUT ANY WARRANTY; without even the implied
   warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
   the GNU Lesser General Public License version 2.1 for more details.

   You should have received a copy of the GNU Lesser General Public
   License version 2.1 along with the Decimal Floating Point C Library;
   if not, write to the Free Software Foundation, Inc., 51 Franklin
   Street, Fifth Floor, Boston, MA 02110-1301 USA.

   Please see dfp/COPYING.txt for more information.  */

#ifndef _DECROUNDTLS_
#define _DECROUNDTLS_

#include <features.h>
__BEGIN_DECLS

extern int * __decrm_location (void);
hidden_proto (__decrm_location)

__END_DECLS

#endif /* _DECROUNDTLS_  */
